import numpy as np
import matplotlib.pyplot as plt
from scipy.ndimage.filters import uniform_filter1d


filename = "../IP5/Terrameter/rawData/fullWaveForm/IP5_Terrameter-fwf.csv"
t, u1, u4, u7 = np.genfromtxt(filename, unpack=True)
# %%
cols1 = ['C0', 'C2', 'C3']
cols2 = ['C9', 'C8', 'C6']
mel = [28, 31, 34]
perc = 1
num = 225
fig, ax = plt.subplots(nrows=3, figsize=(8, 10), sharex=True)
for i, u in enumerate([u1, u4, u7]):
    ax[i].plot(t, u*1000, color=cols2[i], label='raw')
    # ua = np.convolve(u, np.ones(num,), mode='same') / num
    ua = uniform_filter1d(u, size=num)
    ax[i].plot(t, ua*1000, color=cols1[i], label='filtered')
    yl = np.percentile(u, [perc, 100-perc])
    dyl = (yl[1]-yl[0]) * 0.05
    yl[0] -= dyl
    yl[1] += dyl
    ax[i].set_ylim(yl*1000)
    ax[i].set_xlim(min(t), max(t))
    ax[i].grid(True)
    ax[i].set_ylabel('U [mV]')
    ax[i].set_title('MN='+str(mel[i])+'-'+str(mel[i]+1))
    ax[i].legend()

ax[2].set_xlabel('time [s]')
fig.tight_layout()
fig.savefig('figure03.pdf', bbox_inches='tight')
plt.show()
