import numpy as np
import matplotlib.pyplot as plt
import pybert as pb
from pygimli.viewer.mpl import createColorBarOnly
from matplotlib import cm


sip = pb.FDIPdata('../IP1/SIP256C/IP1_SIP256C')
sip.filter(ab=4, kmax=2300)
das = pb.FDIPdata('../IP1/DAS1/IP1_DAS1')
das.filter(ab=4)
# %%
frsip = [0.156, 1.2, 80.]
frdas = [0.125, 1.0, 75.]
rmap = cm.get_cmap('Spectral_r')  # rainbow')
imap = cm.get_cmap('viridis')
imap.set_under('lightgray')
imap.set_over('darkgray')
imap.set_bad('black')
ikw = dict(cMin=1, cMax=120, logScale=True, what='ip', cMap=imap,
           label=r'$-\phi_a$ [mrad]', xlabel='x [m]', colorBar=False)
for bla in [sip, das]:
    bla.PHIA[(bla.PHIA > 0) & (bla.PHIA < 0.001)] = 0.001
    bla.PHIA[(bla.PHIA <= 0)] = 0.0001
# %%
fig, ax = plt.subplots(nrows=4, ncols=2, figsize=(8, 8))
for i in range(3):
    sip.showSingleFrequencyData(fr=frsip[i], ax=ax[i, 0], **ikw)
    das.showSingleFrequencyData(fr=frdas[i], ax=ax[i, 1], **ikw)
    aa = ax[i, 0]
    aa.text(aa.get_xlim()[0]-3, aa.get_ylim()[0]+2, "f="+str(frsip[i])+"Hz")
    aa = ax[i, 1]
    aa.text(aa.get_xlim()[0]-3, aa.get_ylim()[0]+2, "f="+str(frdas[i])+"Hz")

fig.tight_layout()

ikw.pop('what')
ikw.pop('xlabel')
ikw.pop('colorBar')
for aa in ax[3, :]:
    aa.set_visible(False)

cikw = ikw.fromkeys(['cMin', 'cMax', 'logScale', 'cMap', 'label'])
cax = fig.add_axes([0.2, 0.2, 0.6, 0.02])
createColorBarOnly(ax=cax, **ikw)

ax[0, 0].set_title('SIP256C')
ax[0, 1].set_title('DAS-1')

# %%
a = 26
for aa in fig.axes[:-1]:
    for sep in [1, 4, 7]:
        aa.plot(a+np.array([0, 1, 1, 0, 0])+sep/2-0.5,
                sep+np.array([-1, -1, 1, 1, -1])*0.5-1, 'w-')

fig.savefig('figure05.pdf', bbox_inches='tight')
