import numpy as np
import matplotlib.pyplot as plt
import pygimli as pg
from pygimli.viewer.mpl import createColorBarOnly
import pybert as pb
from matplotlib import cm

# %%
mmap = cm.get_cmap('plasma')
mmap.set_under('lightgray')
mmap.set_over('darkgray')
mmap.set_bad('black')
rdict = dict(cMin=5, cMax=500)
mdict = dict(cMin=2.5, cMax=250, colorBar=False, logScale=True,
             cMap=mmap)
# %%
syscal = pb.TDIPdata('../IP1/Syscal/IP1_Syscal.txt')
abemU = pb.TDIPdata('../IP1/Terrameter/rawData/IP1_Terrameter-unprocessed.txt')
abemP = pb.TDIPdata('../IP1/Terrameter/IP1_Terrameter.dip')
dt = np.array([0.06, 0.06, 0.06, 0.12, 0.12, 0.18, 0.24, 0.30, 0.36, 0.42,
               0.54, 0.66, 0.84])
abemU.setGates(dt=dt, delay=0.01)
abemU.filter(ab=4)
abemP.filter(ab=4)
for bla in [syscal, abemU, abemP]:
    bla.MA[(bla.MA > 0) & (bla.MA < 2.5)] = 2.5
    bla.MA[(bla.MA <= 0)] = 0.1
# %%
fig, ax = plt.subplots(nrows=4, ncols=3, figsize=(9, 7),
                       sharex=True, sharey=True)
for i, nr in enumerate([2, 5, 12]):
    syscal.showApparentChargeability(nr=nr, ax=ax[i+1, 0], **mdict)
# %
for i, nr in enumerate([2, 5, 12]):
    abemU.showApparentChargeability(nr=nr, ax=ax[i+1, 1], **mdict)
# %
for i, nr in enumerate([11, 15, 18, 25]):
    abemP.showApparentChargeability(nr=nr, ax=ax[i, 2], **mdict)
    tt = abemP.header['ipGateT']
    aa = ax[i, 2]
    tt= aa.text(aa.get_xlim()[1]+2, aa.get_ylim()[0]-1.5,
                "t={:.2f}-{:.2f}s".format(tt[nr-1], tt[nr]),
                rotation='vertical')

for a in ax[-1, :]:
    a.set_xlabel('x [m]')

fig.tight_layout()
fig.delaxes(ax[0, 0])
fig.delaxes(ax[0, 1])
ax[1, 0].set_title('Syscal')
ax[1, 1].set_title('Terrameter unprocessed')
ax[0, 2].set_title('Terrameter processed')
# %%
a = 26
for aa in fig.axes:
    for sep in [1, 4, 7]:
        aa.plot(a+np.array([0, 1, 1, 0, 0])+sep/2,
                sep+np.array([-1, -1, 1, 1, -1])*0.5-1, 'w-')
# %% Color scale into new independent axis
mdict.pop('colorBar')
# %%
cax = fig.add_axes([0.1, 0.85, 0.5, 0.1])
createColorBarOnly(**mdict, ax=cax, label='m [mV/V]')
cax.set_aspect(0.06)
fig.savefig('figure06.pdf', bbox_inches='tight')
