import numpy as np
import pybert as pb
import pygimli as pg
from pygimli.viewer.mpl import createColorBarOnly

# %%
sip = pb.FDIPdata('../IP1/SIP256C/result/IP1_SIP256C')
das = pb.FDIPdata('../IP1/DAS1/result/IP1_DAS1')
sip.loadResults(loadFit=True)
das.loadResults()  # loadFit=True)
# fdip.fitAllRhoPhi()
# %% read in file
abem = pb.TDIPdata('../IP1/Terrameter/result/IP1_Terrameter.dip')
abem.loadResult(loadColeCole=True)
sysc = pb.TDIPdata('../IP1/Syscal/result/IP1_Syscal.txt')
sysc.loadResult(loadColeCole=True)
# %%
nr = 2
f = sip.freq[nr]
for tdip in [abem, sysc]:
    rhoC = tdip.res * (1 - tdip.m0*(1-1/(1+(1j*2*np.pi*f*tdip.tau)**tdip.c)))
    tdip.phi = -np.angle(rhoC) * 1000

sip.phi = sip.PHI[:, nr] * 1000
das.phi = das.PHI[:, nr] * 1000
# %% define plotting options
rdict = dict(cMin=5, cMax=500, cMap='Spectral_r', logScale=True,
             label=r'resistivity ($\Omega$m)', colorBar=False)
idict = dict(cMin=0, cMax=120, logScale=False, cMap='viridis',
             label=r'$-\phi$ (mrad)', colorBar=False)
# %% create subplots
fig, ax = pb.pg.plt.subplots(nrows=4, ncols=2, figsize=(10, 6),
                             sharex=True, sharey=True)
# %% FDIP data
pg.show(sip.pd, sip.res, ax=ax[0, 0], **rdict)
pg.show(sip.pd, sip.phi, ax=ax[0, 1], **idict)
pg.show(das.pd, das.res, ax=ax[1, 0], **rdict)
pg.show(das.pd, das.phi, ax=ax[1, 1], **idict)
# %% TDIP data
pg.show(abem.pd, abem.res, ax=ax[2, 0], **rdict)
pg.show(abem.pd, abem.phi, ax=ax[2, 1], **idict)
pg.show(sysc.pd, sysc.res, ax=ax[3, 0], **rdict)
pg.show(sysc.pd, sysc.phi, ax=ax[3, 1], **idict)
# %% finish figure and export
ax[0, 0].set_title('FDIP (SIP256C)')
ax[1, 0].set_title('FDIP (DAS-1)')
ax[2, 0].set_title('TDIP (Terrameter)')
ax[3, 0].set_title('TDIP (Syscal)')
for a in ax[-1, :]:
    a.set_xlabel('x (m)')
for a in ax[:, 0]:
    a.set_ylabel('z (m)')
fig.tight_layout()
# %%
rax = fig.add_axes([0.08, -0.05, 0.4, 0.05])
rdict.pop('colorBar', None)
createColorBarOnly(ax=rax, **rdict)
iax = fig.add_axes([0.55, -0.05, 0.4, 0.05])
idict.pop('colorBar', None)
createColorBarOnly(ax=iax, **idict)
# %%
fig.savefig('figure10.pdf', bbox_inches='tight')
