import matplotlib.pyplot as plt
import pybert as pb
from matplotlib import cm
from pygimli.viewer.mpl import createColorBarOnly

fdip = pb.FDIPdata('../IP5/SIP256C/IP5_SIP256C')
fdip.filter(kmax=12600)
#fdip.mask(phimin=1.0)
tdip = pb.TDIPdata('../IP5/Terrameter/IP5_Terrameter.dip')
tdip.MA = tdip.MA.data
# %%
mmap = cm.get_cmap('plasma')
mmap.set_under('lightgray')
mmap.set_over('darkgray')
imap = cm.get_cmap('viridis')
imap.set_under('lightgray')
imap.set_over('darkgray')
rkw = dict(cMin=5, cMax=500, cMap='Spectral_r')
mkw = dict(cMin=2.5, cMax=250, logScale=True, cMap=mmap)
ikw = dict(cMin=1, cMax=200, logScale=True, cMap=imap)
# %%
fdip.PHIA[(fdip.PHIA > 0) & (fdip.PHIA < 0.001)] = 0.001
fdip.PHIA[(fdip.PHIA <= 0)] = 0.0001
tdip.MA[(tdip.MA > 0) & (tdip.MA < 2.5)] = 2.5
tdip.MA[(tdip.MA <= 0)] = 0.1
# %%
fig, ax = plt.subplots(nrows=4, ncols=2, figsize=(9, 7))  # ,
#                       sharex=True, sharey=True)
fdip.showSingleFrequencyData(fr=0, ax=ax[0, 0], what='rhoa', **rkw,
                             colorBar=False)
tdip.showData(ax=ax[0, 1], **rkw, colorBar=False)
tt = [pb.pg.utils.rndig(ti, 2) for ti in tdip.header['ipGateT']]
for i, nr in enumerate([14, 19, 24]):
    tdip.showApparentChargeability(nr=nr, ax=ax[i+1, 1], **mkw, colorBar=False)
    aa = ax[i+1, 1]
#    aa.text(aa.get_xlim()[0]-25, aa.get_ylim()[0]+2,
#            "t="+str(tt[nr])+"-"+str(tt[nr+1]))
    aa.set_title("t="+str(tt[nr])+"-"+str(tt[nr+1])+'s')

for i, nr in enumerate([0, 4, 8]):
    fdip.showSingleFrequencyData(fr=nr, ax=ax[i+1, 0], what='ip', **ikw,
                                 colorBar=False)
    aa = ax[i+1, 0]
#    aa.text(aa.get_xlim()[0]-25, aa.get_ylim()[0]+2,
#            "f="+str(fdip.freq[nr])+"Hz")
    aa.set_title("f="+str(fdip.freq[nr])+"Hz")

rcax = fig.add_axes([0.2, 1.05, 0.6, 0.02])
# icax, mcax = ax[-1, 0], ax[-1, 1]
icax = fig.add_axes([0.07, -0.02, 0.41, 0.02])
mcax = fig.add_axes([0.56, -0.02, 0.41, 0.02])
for a in ax[-1, :]:
    a.set_xlabel('x [m]')
createColorBarOnly(ax=rcax, **rkw, label=r'apparent resistivity [$\Omega$m]')
createColorBarOnly(ax=icax, **ikw, label=r'apparent phase [mrad]')
createColorBarOnly(ax=mcax, **mkw, label=r'apparent chargeability [mV/V]')
fig.tight_layout()
fig.savefig('figure11.pdf', bbox_inches='tight')
