import numpy as np
import pybert as pb
import pygimli as pg

# %%
sip = pb.FDIPdata('../IP5/SIP256C/result/IP5_SIP256C')
sip.loadResults(loadFit=True)
# %% read in file
# filename = 'Profile4-Gradient-8s.tx2'
# filename =
abem = pb.TDIPdata('../IP5/Terrameter/result/IP5_Terrameter.dip')
abem.filter(tmin=0.03)
abem.loadResult(loadColeCole=True)
if 0:
    # %%
    abem.fitModelDecays(useColeCole=True, show=True, mpar=(0.3, 0.1, 1.0),
                        taupar=(1.0, 0.2, 2.0), cpar=(0.3, 0.1, 0.6))
    abem.saveFit()
# %%
# %% fdip.phi = np.max(fdip.PHI, axis=1) * 1000
nr = 0
sip.phi = sip.PHI[:, nr] * 1000
f = sip.freq[nr]
for tdip in [abem]:
    rhoC = tdip.res * (1 - tdip.m0*(1-1/(1+(1j*2*np.pi*f*tdip.tau)**tdip.c)))
    tdip.phi = -np.angle(rhoC) * 1000

# %% define plotting options
rdict = dict(cMin=5, cMax=500, cMap='Spectral_r', logScale=True,
             label=r'resistivity ($\Omega$m)', colorBar=False)
idict = dict(cMin=0, cMax=120, logScale=False, cMap='viridis',
             label=r'$-\phi$ (mrad)', colorBar=False)
# %% create subplots
fig, ax = pb.pg.plt.subplots(nrows=2, ncols=2, figsize=(10, 4),
                             sharex=True, sharey=True)
# % TDIP data
pg.show(abem.pd, abem.res, ax=ax[1, 0], **rdict)
pg.show(abem.pd, abem.phi, ax=ax[1, 1], **idict)
# % FDIP data
pg.show(sip.pd, sip.res, ax=ax[0, 0], **rdict)
pg.show(sip.pd, sip.phi, ax=ax[0, 1], **idict)
# % finish figure and export
ax[0,0].set_xlim(-10,320)
ax[0, 0].set_title('FDIP (SIP256C)')
ax[1, 0].set_title('TDIP (Terrameter)')
for a in ax[-1, :]:
    a.set_xlabel('x (m)')
for a in ax[:, 0]:
    a.set_ylabel('z (m)')
fig.tight_layout()
# %
rax = fig.add_axes([0.08, 0.05, 0.4, 0.05])
rdict.pop('colorBar', None)
pg.viewer.mpl.colorbar.createColorBarOnly(ax=rax, **rdict)
iax = fig.add_axes([0.55, 0.05, 0.4, 0.05])
idict.pop('colorBar', None)
pg.viewer.mpl.colorbar.createColorBarOnly(ax=iax, **idict)
# ax[0, 0].plot([180, 242], [-60, -60], color='red', linewidth=5)
# %%
fig.savefig('figure13.pdf', bbox_inches='tight')
